function matrix = cell2mat_trials(cell_matrix)
%--------------------------------------------------------------------------
% function cell2mat.m - Converts a cell matrix to a zero-padded matrix.
% This function should be used on an MxT cell array of values with M cells
% and T trials.
%
% Usage: matrix = cell2mat(cell_matrix)
%
% Input:  cell_matrix         * MxT cell array of arrays
% Output: matrix              * MxTxP zero-padded matrix
%
% Written by Marshall Crumiller
%--------------------------------------------------------------------------
[M,T] = size(cell_matrix);

% determine the maximum length
max_row = 0;
for i = 1:M
    for t = 1:T
        max_row = max(max_row, length(cell_matrix{i,t}));
    end
end

matrix = single(zeros(M, T, max_row));
% copy cell values into matrix
for i = 1:M
    for t = 1:T
        if(~isempty(cell_matrix{i,t}))
            matrix(i,t,1:length(cell_matrix{i,t})) = cell_matrix{i,t};
        end
    end
end