function [C,G] = entropy_coeffs(coeffs,trial_length)
%ENTROPY_COEFFS   calculate entropy from set of coefficients
%   ent = ENTROPY_COEFFS(coeffs)
%   
%   Input:  coeffs              * MxTxF matrix of coefficients, or
%                                 TxF matrix of coefficients
%   Output: C                   * CxF matrix of cell-wise entropy values
%                                 per dimensional unit
%           G                   * 1xF vector of group-wise entropy per
%                                 dimensional unit
%
%   Written by Marshall Crumiller
%   email: mcrumiller@gmail.com
%--------------------------------------------------------------------------
% multiple cells
if(ndims(coeffs)==3)
    cov_mat=cellfun(@cov,num2cell(permute(coeffs,[2 1 3]),[1 2]),'UniformOutput',false);
    vars=cell2mat(cellfun(@diag,cov_mat,'UniformOutput',false));
    eigenvalues=cell2mat(cellfun(@eig,cov_mat,'UniformOutput',false));
    C=squeeze(1/2*log2(2*pi*exp(1)*vars));
    G=squeeze(sum(1/2*log2(2*pi*exp(1)*eigenvalues),1));
else
    v=var(coeffs,[],1);
    C=1/2*log2(2*pi*exp(1)*v);
    G=C';
end

if(exist('trial_length','var') && ~isempty(trial_length))
    C=C/trial_length;
    G=G/trial_length;
end