function [I_cell, I_group, R] = information_coeffs(coeffs_repeat,coeffs_unique,trial_length)
%INFORMATION_COEFFS   calculate information of coefficients
%   [] = INFORMATION_COEFFS() 
%   
%   Input:  coeffs_repeat               * repeat fourier coefficients
%           coeffs_unique               * unique fourier coefficients
%           (*)trial_length             * length of trial
%   Output: I_cell                      * CxF vector of cell information
%           I_group                     * 1xF vector of group information
%           R                           * 1xF vector of group redundancy
%   (*) = optional
%
%   Written by Marshall Crumiller
%   email: mcrumiller@gmail.com
%--------------------------------------------------------------------------
[Crep,Grep] = entropy_coeffs(coeffs_repeat);
[Cuni,Guni] = entropy_coeffs(coeffs_unique);

I_cell=(Cuni-Crep);
I_group=(Guni-Grep);
R = 1-(sum(I_group)./sum(I_cell(:)));

if(exist('trial_length','var') && ~isempty(trial_length))
    I_cell=I_cell/trial_length;
    I_group=I_group/trial_length;
end